[suite recv_cmd]
caption = receivers
[subcommand afh]
	purpose = make an audio stream from a local file
	[description]
		The afh (audio format handler) receiver extracts selected parts of
		the given audio file without decoding the file. Only complete chunks
		with respect to the underlying audio format are extracted.
	[/description]
	[option filename]
		short_opt = f
		summary = file to open
		typestr = filename
		arg_info = required_arg
		arg_type = string
	[option begin-chunk]
		short_opt = b
		summary = skip the beginning of the file
		typestr = chunk_num
		arg_info = required_arg
		arg_type = int32
		[help]
			The argument must be an integer between -num_chunks and num_chunks -
			1, inclusively, where num_chunks is the total number of chunks. If
			chunk_num is negative, the given number of chunks are counted backwards
			from the end of the file. For example --begin-chunk -100 instructs
			the afh receiver to start at chunk num_chunks - 100. This is useful
			for cutting off the beginning of an audio file.
		[/help]
	[option end-chunk]
		short_opt = e
		summary = only write up to chunk chunk_num
		typestr = chunk_num
		arg_info = required_arg
		arg_type = int32
		[help]
			For the chunk_num argument the same rules as for --begin-chunk
			apply. The default is to write up to the last chunk.
		[/help]
	[option just-in-time]
		short_opt = j
		summary = use timed writes
		[help]
			Write the specified data chunks 'just in time', i.e., delay the write
			until data is needed by the decoder/player for an uninterrupted audio
			stream. This may be useful for third-party software.
		[/help]
	[option no-header]
		short_opt = h
		summary = do not write an audio file header
		[help]
			Some audio formats store information about the audio file in
			a format-specific header which is needed to decode any part of
			the file. For such formats the afh receiver generates a suitable
			header. This option changes the default behaviour, i.e. no header
			is written.
		[/help]
[subcommand http]
	purpose = receive an audio stream over HTTP
	m4_include(host.m4)
	m4_include(port.m4)
[subcommand dccp]
	purpose = receive an audio stream over DCCP
	m4_include(host.m4)
	m4_include(port.m4)
	[option ccid]
		short_opt = c
		summary = CCID preference(s) for this connection
		typestr = id
		arg_info = required_arg
		arg_type = uint32
		flag multiple
		[help]
			When present exactly once, this option mandates the CCID for the
			sender-receiver connection. If it is passed more than once, it sets
			a preference list where the order of appearance signifies descending
			priority. For example, passing 4, 2, 3 creates the preference list
			(CCID-4, CCID-2, CCID-3), assigning CCID-4 highest preference.

			The request is reconciled with the CCIDs on the server through the
			'server-priority' mechanism of RFC 4340 6.3.1/10. The server CCIDs
			can be listed by calling 'para_client sender dccp status'.
		[/help]
[subcommand udp]
	purpose = receive an audio stream over UDP
	[option host]
		short_opt = i
		summary = IP address or hostname
		typestr = host
		arg_info = required_arg
		arg_type = string
		default_val = 224.0.1.38
		[help]
			The default address resolves to DANTZ.MCAST.NET and activates
			multicast.
		[/help]
	m4_include(port.m4)
	[option iface]
		summary = receiving udp multicast interface
		typestr = iface-name
		arg_info = required_arg
		arg_type = string
